@@ -12,8 +12,7 @@ __all__ = ['Configuration', 'ConfigurationSupplyPeriod', 'Production']
 supply_period = fields.TimeDelta("Supply Period")
 
 
-class Configuration:
-    __metaclass__ = PoolMeta
+class Configuration(metaclass=PoolMeta):
     __name__ = 'production.configuration'
     supply_period = fields.MultiValue(supply_period)
 
@@ -24,8 +23,7 @@ class ConfigurationSupplyPeriod(ModelSQL, ValueMixin):
     supply_period = supply_period
 
 
-class Production:
-    __metaclass__ = PoolMeta
+class Production(metaclass=PoolMeta):
     __name__ = 'production'
 
     @classmethod
@@ -90,8 +88,10 @@ class Production:
             product_ids = [p.id for p in sub_products]
             with Transaction().set_context(forecast=True,
                     stock_date_end=today):
-                pbl = Product.products_by_location(warehouse_ids,
-                    product_ids, with_childs=True)
+                pbl = Product.products_by_location(
+                    warehouse_ids,
+                    with_childs=True,
+                    grouping_filter=(product_ids,))
 
             # order product by supply period
             products_period = sorted((p.get_supply_period(), p)
@@ -202,9 +202,11 @@ class Production:
             with Transaction().set_context(forecast=True,
                     stock_date_start=current_date,
                     stock_date_end=current_date):
-                pbl = Product.products_by_location([location_id],
-                    product_ids, with_childs=True)
-            for key, qty in pbl.iteritems():
+                pbl = Product.products_by_location(
+                    [location_id],
+                    with_childs=True,
+                    grouping_filter=(product_ids,))
+            for key, qty in pbl.items():
                 _, product_id = key
                 current_qties[product_id] += qty
 
